unit Entities;

interface

uses
  SysUtils,
  Generics.Collections,
  Aurelius.Mapping.Attributes,
  Aurelius.Types.Blob,
  Aurelius.Types.DynamicProperties,
  Aurelius.Types.Nullable,
  Aurelius.Types.Proxy;

type
  TDET_1_TABLE = class;
  TDET_2_TABLE = class;
  TMASTER_TABLE = class;

  [Entity]
  [Table('MASTER_TABLE')]
  [Id('FID_MAS', TIdGenerator.IdentityOrSequence)]
  TMASTER_TABLE = class
  private
    [Column('ID_MAS', [TColumnProp.Required])]
    FID_MAS: Integer;

    [Column('DESCRIPTION', [], 50)]
    FDESCRIPTION: Nullable<string>;

    [Column('DATE_COLL', [])]
    FDATE_COLL: Nullable<string>;

    [Column('IN_COLL', [TColumnProp.Required])]
    FIN_COLL: Boolean;

    [Column('INFO_CLI', [], 50)]
    FINFO_CLI: Nullable<string>;

    [Column('TEMPER', [], 10, 2)]
    FTEMPER: Nullable<Double>;

    //[ManyValuedAssociation([TAssociationProp.Lazy], CascadeTypeAllRemoveOrphan)]
    //[ForeignJoinColumn('ID_MAS', [TColumnProp.Required])]
    //FDET_1_TABLE: Proxy<TList<TDET_1_TABLE>>;

    [ManyValuedAssociation([TAssociationProp.Lazy], CascadeTypeAllRemoveOrphan, 'FID_MAS')]
    FDET_1_TABLE: Proxy<TList<TDET_1_TABLE>>;

    Function Get_DET_1_TABLE: TList<TDET_1_TABLE>;

  public
    constructor Create; overload;
    destructor Destroy; override;

    property ID_MAS: Integer read FID_MAS write FID_MAS;
    property DESCRIPTION: Nullable<string> read FDESCRIPTION write FDESCRIPTION;
    property DATE_COLL: Nullable<string> read FDATE_COLL write FDATE_COLL;
    property IN_COLL: Boolean read FIN_COLL write FIN_COLL;
    property INFO_CLI: Nullable<string> read FINFO_CLI write FINFO_CLI;
    property TEMPER: Nullable<Double> read FTEMPER write FTEMPER;
  end;

  [Entity]
  [Table('DET_1_TABLE')]
  [Id('FID_MAS', TIdGenerator.None)]
  [Id('FID_DET1', TIdGenerator.None)]
  TDET_1_TABLE = class
  private
    //[Column('ID_MAS', [TColumnProp.Required])]
    //FID_MAS: Integer;

    [Column('ID_DET1', [TColumnProp.Required])]
    FID_DET1: Integer;

    [Column('DESCRIPTION', [], 50)]
    FDESCRIPTION: Nullable<string>;

    [Column('DATE_COLL', [])]
    FDATE_COLL: Nullable<string>;

    [Column('IN_COLL', [TColumnProp.Required])]
    FIN_COLL: Boolean;

    [Column('INFO_CLI', [], 50)]
    FINFO_CLI: Nullable<string>;

    [Column('TEMPER', [], 10, 2)]
    FTEMPER: Nullable<Double>;

    [Association([TAssociationProp.Lazy], CascadeTypeAllButRemove)]
    [JoinColumn('ID_MAS', [TColumnProp.Required])]
    FID_MAS: TMASTER_TABLE;

    {
    [ManyValuedAssociation([TAssociationProp.Lazy], CascadeTypeAllRemoveOrphan)]
    [ForeignJoinColumn('ID_MAS', [TColumnProp.Required])]
    [ForeignJoinColumn('ID_DET1', [TColumnProp.Required])]
    FDET_2_TABLE: Proxy<TList<TDET_2_TABLE>>;
    }

    //Function Get_DET_2_TABLE: TList<TDET_2_TABLE>;

  public
    //property ID_MAS: Integer read TMASTER_TABLE write FID_MAS;
    property ID_DET1: Integer read FID_DET1 write FID_DET1;
    property DESCRIPTION: Nullable<string> read FDESCRIPTION write FDESCRIPTION;
    property DATE_COLL: Nullable<string> read FDATE_COLL write FDATE_COLL;
    property IN_COLL: Boolean read FIN_COLL write FIN_COLL;
    property INFO_CLI: Nullable<string> read FINFO_CLI write FINFO_CLI;
    property TEMPER: Nullable<Double> read FTEMPER write FTEMPER;
  end;

  [Entity]
  [Table('DET_2_TABLE')]
  [Id('FID_MAS', TIdGenerator.None)]
  [Id('FID_DET2', TIdGenerator.None)]
  TDET_2_TABLE = class
  private
    [Column('ID_MAS', [TColumnProp.Required])]
    FID_MAS: Integer;

    [Column('ID_DET1', [TColumnProp.Required])]
    FID_DET1: Integer;

    [Column('ID_DET2', [TColumnProp.Required])]
    FID_DET2: Integer;

    [Column('DESCRIPTION', [], 50)]
    FDESCRIPTION: Nullable<string>;

    [Column('DATE_COLL', [])]
    FDATE_COLL: Nullable<string>;

    [Column('IN_COLL', [TColumnProp.Required])]
    FIN_COLL: Boolean;

    [Column('INFO_CLI', [], 50)]
    FINFO_CLI: Nullable<string>;

    [Column('TEMPER', [], 10, 2)]
    FTEMPER: Nullable<Double>;

  public
    property ID_MAS: Integer read FID_MAS write FID_MAS;
    property ID_DET1: Integer read FID_DET1 write FID_DET1;
    property ID_DET2: Integer read FID_DET2 write FID_DET2;
    property DESCRIPTION: Nullable<string> read FDESCRIPTION write FDESCRIPTION;
    property DATE_COLL: Nullable<string> read FDATE_COLL write FDATE_COLL;
    property IN_COLL: Boolean read FIN_COLL write FIN_COLL;
    property INFO_CLI: Nullable<string> read FINFO_CLI write FINFO_CLI;
    property TEMPER: Nullable<Double> read FTEMPER write FTEMPER;
  end;


implementation


constructor TMASTER_TABLE.Create;
begin
  FDET_1_TABLE.SetInitialValue(TList<TDET_1_TABLE>.Create);
end;

function TMASTER_TABLE.Get_DET_1_TABLE: TList<TDET_1_TABLE>;
begin
  Result := FDET_1_TABLE.Value;
end;

destructor TMASTER_TABLE.Destroy;
begin
  FDET_1_TABLE.DestroyValue;
  inherited;
end;



initialization
  RegisterEntity(TDET_1_TABLE);
  RegisterEntity(TDET_2_TABLE);
  RegisterEntity(TMASTER_TABLE);

finalization

end.
